==> haskell-text-show-3.9-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-show
version:              3.9
visibility:           public
id:                   text-show-3.9-CJIj23gULP1BilFguJO1zH
key:                  text-show-3.9-CJIj23gULP1BilFguJO1zH
license:              BSD-3-Clause
copyright:            (C) 2014-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/text-show
synopsis:             Efficient conversion of values into Text
description:
    @text-show@ offers a replacement for the @Show@ typeclass intended
    for use with @Text@ instead of @String@s. This package was created
    in the spirit of
    @<http://hackage.haskell.org/package/bytestring-show bytestring-show>@.

    At the moment, @text-show@ provides instances for most data
    types in the @<http://hackage.haskell.org/package/array array>@,
    @<http://hackage.haskell.org/package/base base>@,
    @<http://hackage.haskell.org/package/bytestring bytestring>@, and
    @<http://hackage.haskell.org/package/text text>@ packages.
    Therefore, much of the source code for @text-show@ consists of
    borrowed code from those packages in order to ensure that the
    behaviors of @Show@ and @TextShow@ coincide.

    For most uses, simply importing "TextShow"
    will suffice:

    @
    module Main where

    import TextShow

    main :: IO ()
    main = printT (Just \"Hello, World!\")
    @

    See also the
    <https://github.com/RyanGlScott/text-show/wiki/Naming-conventions naming conventions>
    page.

    Support for automatically deriving @TextShow@ instances can be found
    in the "TextShow.TH" and "TextShow.Generic" modules.

category:             Text
abi:                  d22fcb4c7002807a8c773de85a5ea582
exposed:              True
exposed-modules:
    TextShow TextShow.Control.Applicative TextShow.Control.Concurrent
    TextShow.Control.Exception TextShow.Control.Monad.ST
    TextShow.Data.Array TextShow.Data.Bool TextShow.Data.ByteString
    TextShow.Data.Char TextShow.Data.Complex TextShow.Data.Data
    TextShow.Data.Dynamic TextShow.Data.Either TextShow.Data.Fixed
    TextShow.Data.Floating TextShow.Data.Functor.Compose
    TextShow.Data.Functor.Identity TextShow.Data.Functor.Product
    TextShow.Data.Functor.Sum TextShow.Data.Integral TextShow.Data.List
    TextShow.Data.List.NonEmpty TextShow.Data.Maybe
    TextShow.Data.Monoid TextShow.Data.OldTypeable TextShow.Data.Ord
    TextShow.Data.Proxy TextShow.Data.Ratio TextShow.Data.Semigroup
    TextShow.Data.Text TextShow.Data.Tuple TextShow.Data.Type.Coercion
    TextShow.Data.Type.Equality TextShow.Data.Typeable
    TextShow.Data.Version TextShow.Data.Void TextShow.Debug.Trace
    TextShow.Debug.Trace.Generic TextShow.Debug.Trace.TH
    TextShow.Foreign.C.Types TextShow.Foreign.Ptr TextShow.Functions
    TextShow.GHC.Conc.Windows TextShow.GHC.Event
    TextShow.GHC.Fingerprint TextShow.GHC.Generics
    TextShow.GHC.RTS.Flags TextShow.GHC.Stack TextShow.GHC.StaticPtr
    TextShow.GHC.Stats TextShow.GHC.TypeLits TextShow.Generic
    TextShow.Numeric.Natural TextShow.System.Exit TextShow.System.IO
    TextShow.System.Posix.Types TextShow.TH TextShow.Text.Read

hidden-modules:
    TextShow.Classes TextShow.Data.Typeable.Utils
    TextShow.FromStringTextShow TextShow.Instances TextShow.Options
    TextShow.TH.Internal TextShow.TH.Names TextShow.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/text-show-3.9
library-dirs:         /usr/lib/ghc-8.10.4/site-local/text-show-3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/text-show-3.9
hs-libraries:         HStext-show-3.9-CJIj23gULP1BilFguJO1zH
includes:             generic.h
depends:
    array-0.5.4.0 base-4.14.1.0
    base-compat-batteries-0.11.2-DmK8Qtkle1zLxk1WZtfHfa
    bifunctors-5.5.11-Ltmgq87h2cQKTTlGecsQMH bytestring-0.10.12.0
    containers-0.6.2.1 generic-deriving-1.14-EVA55UTAXiN6AI9ys4c1ie
    ghc-boot-th-8.10.4 ghc-prim-0.6.1 integer-gmp-1.0.3.0
    template-haskell-2.16.0.0 text-1.2.4.1
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:   /usr/share/doc/haskell-text-show/html/text-show.haddock
haddock-html:         /usr/share/doc/haskell-text-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-show-3.9-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-show
version:              3.9
visibility:           public
id:                   text-show-3.9-KUSoe1zzCCmgGahoMAnS5
key:                  text-show-3.9-KUSoe1zzCCmgGahoMAnS5
license:              BSD-3-Clause
copyright:            (C) 2014-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/text-show
synopsis:             Efficient conversion of values into Text
description:
    @text-show@ offers a replacement for the @Show@ typeclass intended
    for use with @Text@ instead of @String@s. This package was created
    in the spirit of
    @<http://hackage.haskell.org/package/bytestring-show bytestring-show>@.

    At the moment, @text-show@ provides instances for most data
    types in the @<http://hackage.haskell.org/package/array array>@,
    @<http://hackage.haskell.org/package/base base>@,
    @<http://hackage.haskell.org/package/bytestring bytestring>@, and
    @<http://hackage.haskell.org/package/text text>@ packages.
    Therefore, much of the source code for @text-show@ consists of
    borrowed code from those packages in order to ensure that the
    behaviors of @Show@ and @TextShow@ coincide.

    For most uses, simply importing "TextShow"
    will suffice:

    @
    module Main where

    import TextShow

    main :: IO ()
    main = printT (Just \"Hello, World!\")
    @

    See also the
    <https://github.com/RyanGlScott/text-show/wiki/Naming-conventions naming conventions>
    page.

    Support for automatically deriving @TextShow@ instances can be found
    in the "TextShow.TH" and "TextShow.Generic" modules.

category:             Text
abi:                  1c0a7ffd920176b8cc67987b794c8768
exposed:              True
exposed-modules:
    TextShow TextShow.Control.Applicative TextShow.Control.Concurrent
    TextShow.Control.Exception TextShow.Control.Monad.ST
    TextShow.Data.Array TextShow.Data.Bool TextShow.Data.ByteString
    TextShow.Data.Char TextShow.Data.Complex TextShow.Data.Data
    TextShow.Data.Dynamic TextShow.Data.Either TextShow.Data.Fixed
    TextShow.Data.Floating TextShow.Data.Functor.Compose
    TextShow.Data.Functor.Identity TextShow.Data.Functor.Product
    TextShow.Data.Functor.Sum TextShow.Data.Integral TextShow.Data.List
    TextShow.Data.List.NonEmpty TextShow.Data.Maybe
    TextShow.Data.Monoid TextShow.Data.OldTypeable TextShow.Data.Ord
    TextShow.Data.Proxy TextShow.Data.Ratio TextShow.Data.Semigroup
    TextShow.Data.Text TextShow.Data.Tuple TextShow.Data.Type.Coercion
    TextShow.Data.Type.Equality TextShow.Data.Typeable
    TextShow.Data.Version TextShow.Data.Void TextShow.Debug.Trace
    TextShow.Debug.Trace.Generic TextShow.Debug.Trace.TH
    TextShow.Foreign.C.Types TextShow.Foreign.Ptr TextShow.Functions
    TextShow.GHC.Conc.Windows TextShow.GHC.Event
    TextShow.GHC.Fingerprint TextShow.GHC.Generics
    TextShow.GHC.RTS.Flags TextShow.GHC.Stack TextShow.GHC.StaticPtr
    TextShow.GHC.Stats TextShow.GHC.TypeLits TextShow.Generic
    TextShow.Numeric.Natural TextShow.System.Exit TextShow.System.IO
    TextShow.System.Posix.Types TextShow.TH TextShow.Text.Read

hidden-modules:
    TextShow.Classes TextShow.Data.Typeable.Utils
    TextShow.FromStringTextShow TextShow.Instances TextShow.Options
    TextShow.TH.Internal TextShow.TH.Names TextShow.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/text-show-3.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/text-show-3.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/text-show-3.9
hs-libraries:         HStext-show-3.9-KUSoe1zzCCmgGahoMAnS5
includes:             generic.h
depends:
    array-0.5.4.0 base-4.14.2.0
    base-compat-batteries-0.11.2-DVJuxp3UWFLDDlHVEHZRmB
    bifunctors-5.5.11-KIJIfjFRTJDJ2IFv8ycKWx bytestring-0.10.12.0
    containers-0.6.4.1 generic-deriving-1.14-FmjLLpmAKwHIAYmj7ohR47
    ghc-boot-th-8.10.5 ghc-prim-0.6.1 integer-gmp-1.0.3.0
    template-haskell-2.16.0.0 text-1.2.4.1
    th-abstraction-0.4.2.0-5X2XqBZ7rCLBwJXut5dQBZ
    th-lift-0.8.2-A94jWiBJfaQF1v2Vq9YgsH transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:   /usr/share/doc/haskell-text-show/html/text-show.haddock
haddock-html:         /usr/share/doc/haskell-text-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
